@@ -28,7 +28,7 @@
 #' @return Character vector
 .missing_variables <- function(x) {
   stopifnot(inherits(x, "ghcn_daily") || inherits(x, "ghcn_monthly") || inherits(x, "ghcn_annual"))
-  ans <- setdiff(c("tmin", "tmax", "prcp"), colnames(x))
+  ans <- setdiff(c("tavg", "tmin", "tmax", "prcp"), colnames(x))
   return(ans)
 }
 
@@ -41,7 +41,7 @@
   stopifnot(inherits(x, "ghcn_daily") || inherits(x, "ghcn_monthly") || inherits(x, "ghcn_annual"))
 
   # add variables to not break summarize
-  if (!all(c("tmin", "tmax", "prcp") %in% colnames(x))) {
+  if (!all(c("tavg", "tmin", "tmax", "prcp") %in% colnames(x))) {
     missing_variables <- .missing_variables(x)
     for (v in missing_variables) {
       x[[v]] <- -9999
